import sys
import argparse
import subprocess
import platform
import pathlib

from ..compiler import Compiler


def main():
    argparser = argparse.ArgumentParser(
        prog="autoconfc",
        description="A simple utility to configure PyConfC files",
    )

    argparser.add_argument(
        "-p", "--path", type=str, default=".", help="Path to the AutoConfC file")

    args = argparser.parse_args(sys.argv[1:])

    path = pathlib.Path(args.path) / "configure.in"

    if not path.is_file():
        print(f"{path} is not a file")

        exit(1)

    text = path.read_text()

    compiler = Compiler(text)

    o_path = pathlib.Path(args.path) / "configure"
    o_path.write_text(compiler.compile())

    if platform.system() == "Linux" or platform.system() == "Darwin" or platform.system() == "FreeBSD":
        subprocess.run(["chmod", "+x", o_path])

    print(f"{o_path} created")


if __name__ == "__main__":
    main()
