import sys
import pathlib
import platform
import os

LINUX = platform.system() == "Linux"
DARWIN = platform.system() == "Darwin"
WINDOWS = platform.system() == "Windows"
UNIX = not WINDOWS

env = {}
assign_method = ":="


def set(name, value):
    global env

    if isinstance(value, str):
        env[name] = value

    else:
        env[name] = str(value)


def get(name):
    try:
        return env[name]

    except:
        return None


def find(var, tool, paths=os.getenv("PATH").split(":"), fallback=None):
    print(f"checking {tool} (as {var})... ", end="")

    for path in paths:
        fpath = pathlib.Path(path) / tool

        if fpath.is_file():
            set(var, fpath)

            print(fpath)

            return

    if fallback:
        set(var, fallback)

        print(f"{fallback} (fallback)")

    else:
        print("not found")

        exit(1)


def replace_var(text):
    global env

    for k, v in env.items():
        text = text.replace(f"${{{k}}}", v)

    return text


def reset():
    global env

    env = {}


def to_str(method=assign_method):
    global env

    return "\n".join(f"{k} {method} {v}" for k, v in env.items())


def init(src=str(pathlib.Path(sys.argv[0]).parent), dst="."):
    set("SRC", pathlib.Path(src).absolute().resolve())
    set("DST", pathlib.Path(dst).absolute().resolve())


def configure(method=assign_method, tabsize=4):
    fpath = pathlib.Path(get("SRC")) / "Makefile.in"
    ftext = fpath.read_text()

    ftext = f"{to_str(method)}\n\n{ftext}"

    new_fpath = pathlib.Path(get("DST")) / "Makefile"
    new_fpath.write_text(ftext.replace(" " * tabsize, "\t"))
